@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: main.php,v 1.6 2005/03/18 19:08:04 tohokuaiki Exp $
+ * $Id: main.php,v 1.10 2005/04/12 15:20:14 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
  *
@@ -65,6 +65,7 @@ define('_BL_RSS_RECENT', 'Syndicate weBLogs');
 define('_BL_RSS_RECENT_FOR', "Syndicate %s's entries");
 define('_BL_UPDATEPING','Send update ping');
 define('_BL_TRACKBACK','Trackback URL');
+define('_BL_TRACKBACKS','Trackbacks');
 define('_BL_TRACKBACK_DSC','Please fill trackback URLs set apart by new line');
 define('_BL_TRACKBACK_ADMIN','Recieved Trackback');
 define('_BL_TRACKBACK_DELETE',_DELETE);
@@ -91,8 +92,45 @@ define('_BL_READS', 'Reads');
 define('_BL_NEXT', 'Next entry');
 define('_BL_PREV', 'Previous entry');
 
+// division separator
+define('_BL_ENTRY_SEPARATOR' , 'Entry Separator');
+define('_BL_ENTRY_SEPARATOR_CAPTION' , 'This separator divides the first half and the latter half of entries. Full entry is shown at detail view');
+define('_BL_ENTRY_SEPARATOR_VALUE' , 'Click this button to insert separator');
+define('_BL_ENTRY_SEPARATOR_NEXT' , '...read more');
+
+// member only delimeter
+define('_BL_MEMBER_ONLY_READ' , 'Only member');
+define('_BL_MEMBER_ONLY_READ_CAPTION' , 'Only member can read below this separator');
+define('_BL_MEMBER_ONLY_READ_VALUE' , 'Click this button to insert separator');
+define('_BL_MEMBER_ONLY_READ_MORE' , 'The member registration is necessary for you to read more.');
+
+// image manager tray
+define('_BL_WEBLOG_IMAGEMANAGER' , 'Image Manager');
+define('_BL_WEBLOG_IMAGEMANAGER_CAUTION' , '"weBLog imagemanager requires PHP-GD2 extension. Your environment is not valid."');
+
 // %s is trackback
 define('_BL_TRACKBACK_ANOUNCE' , 'Trackback URL of this entry');
 define('_BL_TRACKBACK_TRANSMIT' , 'This entry trackbacks to below URL');
 define('_BL_TRACKBACK_RECIEVED' , 'Trackbacks to this entry');
+
+// %s is uname
+define('_BL_TRACKBACKS_FOR','to %s\'s Entries ');
+define('_BL_COMMENTS_FOR','for %s\'s Entries ');
+
+
+// use weBLog imagemanager :: myalbum-P
+define("_BL_ALBM_PHOTOUPLOAD","Photo Upload");
+define("_BL_ALBM_MAXPIXEL","Max pixel size");
+define("_BL_ALBM_MAXSIZE","Max file size(byte)");
+define("_BL_ALBM_PHOTOTITLE","Title");
+define("_BL_ALBM_PHOTOCAT","Category");
+define("_BL_ALBM_SELECTFILE","Select photo");
+
+define("_BL_ALBM_PHOTODEL","Delete photo?");
+define("_BL_ALBM_DELETINGPHOTO","Deleting photo");
+define("_BL_ALBM_RECEIVED","We received your Photo. Thanks!");
+define("_BL_ALBM_MUSTREGFIRST","Sorry, you don't have the permission to perform this action.<br>Please register or login first!");
+define("_BL_ALBM_NOIMAGESPECIFIED","Error: No photo is uploaded");
+define("_BL_ALBM_FILEERROR","Error: Photos are too big or some troubles about configuration has occurred");
+define("_BL_ALBM_FILEREADERROR","Error: Photos are not readable.");
 ?>
\ No newline at end of file
