@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: modinfo.php,v 1.5 2005/03/13 07:07:57 tohokuaiki Exp $
+ * $Id: modinfo.php,v 1.9 2005/04/13 06:18:31 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
  *
@@ -60,6 +60,16 @@ define('_MI_WEBLOG_RECENT_BNAME1','Recent weBLogs');
 define('_MI_WEBLOG_RECENT_BNAME1_DESC','Recent weBLog Entries');
 define('_MI_WEBLOG_TOP_WEBLOGS','Top weBLogs');
 define('_MI_WEBLOG_TOP_WEBLOGS_DESC','Top weBLogs');
+define('_MI_WEBLOG_USERS_WEBLOGS','Users\' weBLogs');
+define('_MI_WEBLOG_USERS_WEBLOGS_DESC','Recent weBLogs group by user');
+define('_MI_WEBLOG_RECENT_TRACKBACKS','Recent Trackbacks');
+define('_MI_WEBLOG_RECENT_TRACKBACKS_DESC','Recent Recieved Trackbacks ');
+define('_MI_WEBLOG_RECENT_COMMENTS','Recent Comments');
+define('_MI_WEBLOG_RECENT_COMMENTS_DESC','Recent Comments to weBLog entries');
+define('_MI_WEBLOG_LINKS','weBLog owner\'s Links');
+define('_MI_WEBLOG_LINKS_DESC','Links integrated with a links module');
+define('_MI_WEBLOG_RECENT_IMAGES','Recent Images');
+define('_MI_WEBLOG_RECENT_IMAGES_DESC','Recent Images used by weBLog');
 
 // Config Settings
 define('_MI_WEBLOG_NUMPERPAGE','Number of entries per page');
@@ -97,6 +107,7 @@ define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','Display details about a weBLog entry');
 define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','RSS feed of weBLog entries');
 define('_MI_WEBLOG_TEMPLATE_PRINTDSC','Printer friendly page');
 define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','Monthly archives');
+define('_MI_WEBLOG_TEMPLATE_IMAGEMANAGERDSC','weBLog Image Manager');
 
 define('_MI_WEBLOG_EDITORHEIGHT','Height of editor box (lines)');
 define('_MI_WEBLOG_EDITORHEIGHTDSC','');
@@ -112,4 +123,36 @@ define('_MI_WEBLOG_RSSSHOW','Show an icon linked to RSS feed');
 define('_MI_WEBLOG_RSSSHOWDSC','');
 define('_MI_WEBLOG_RSSMAX','The number of entries to be fed in RSS');
 define('_MI_WEBLOG_RSSMAXDSC','');
+
+define('_MI_WEBLOG_USESEPARATOR','use entry division function');
+define('_MI_WEBLOG_USESEPARATORDSC','inserting separator , you can divide entry as first half and latter half. First half is shown at index.php and Full entry is shown at details.php');
+define('_MI_WEBLOG_USESMEMBERONLY','use menber only readable function');
+define('_MI_WEBLOG_USESMEMBERONLYDSC','inserting separator , you can make part of entry which only registered member can read.');
+define('_MI_WEBLOG_USEIMAGEMANAGER','use weBLog Image manager');
+define('_MI_WEBLOG_USEIMAGEMANAGERDSC','You can use weBLog image manager different with XOOPS core image manager. It can deal thumbnail view.');
+
+
+// myalbum-P imagemanager
+// Config Items
+define( "_MI_ALBM_CFG_PHOTOSPATH" , "Path to photos" ) ;
+define( "_MI_ALBM_CFG_DESCPHOTOSPATH" , "Path from the directory installed XOOPS.<br />(The first character must be '/'. The last character should not be '/'.)<br />This directory's permission is 777 or 707 in unix." ) ;
+define( "_MI_ALBM_CFG_THUMBSPATH" , "Path to thumbnails" ) ;
+define( "_MI_ALBM_CFG_DESCTHUMBSPATH" , "Same as 'Path to photos'." ) ;
+//define( "_MI_ALBM_CFG_THUMBWIDTH" , "Thumb Image Width" ) ;
+//define( "_MI_ALBM_CFG_DESCTHUMBWIDTH" , "The height of thumbs will be decided from the width automatically." ) ;
+define( "_MI_ALBM_CFG_THUMBSIZE" , "Size of thumbnails (pixel)" ) ;
+define( "_MI_ALBM_CFG_THUMBRULE" , "Calc rule for building thumbnails" ) ;
+define( "_MI_ALBM_CFG_WIDTH" , "Max photo width" ) ;
+define( "_MI_ALBM_CFG_DESCWIDTH" , "This means the photo's width to be resized.<br />If you use GD without truecolor, this means the limitation of width." ) ;
+define( "_MI_ALBM_CFG_HEIGHT" , "Max photo height" ) ;
+define( "_MI_ALBM_CFG_DESCHEIGHT" , "Same as 'Max photo width'." ) ;
+define( "_MI_ALBM_CFG_FSIZE" , "Max file size" ) ;
+define( "_MI_ALBM_CFG_DESCFSIZE" , "The limitation of the size of uploading file.(byte)" ) ;
+define( "_MI_ALBM_CFG_MIDDLEPIXEL" , "Max image size in single view" ) ;
+define( "_MI_ALBM_CFG_DESCMIDDLEPIXEL" , "Specify (width)x(height)<br />eg) 480x480" ) ;
+
+define( "_MI_ALBUM_OPT_CALCFROMWIDTH" , "width:specified  height:auto" ) ;
+define( "_MI_ALBUM_OPT_CALCFROMHEIGHT" , "width:auto  width:specified" ) ;
+define( "_MI_ALBUM_OPT_CALCWHINSIDEBOX" , "put in specified size squre" ) ;
+
 ?>
\ No newline at end of file
