@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: post.php,v 1.10 2005/03/14 17:37:32 tohokuaiki Exp $
+ * $Id: post.php,v 1.14 2005/04/12 15:13:54 tohokuaiki Exp $
  * Copyright (c) 2003 by Hiro SAKAI <http://wellwine.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@ include_once(sprintf('%s/class/xoopstree.php', XOOPS_ROOT_PATH));
 include_once(sprintf('%s/modules/%s/class/class.weblog.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 include_once(sprintf('%s/modules/%s/class/class.weblogcategories.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 include_once(sprintf('%s/modules/%s/class/class.weblogtrackback.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
+include_once(sprintf('%s/modules/%s/include/gtickets.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
 
 $weblog =& Weblog::getInstance();
 $weblogcat =& WeblogCategories::getInstance();
@@ -50,22 +51,39 @@ function &getEntry($post) {
     return $entry;
 }
 
-function weblog_confirm($hiddens, $action, $msg, $submit='') {
+function weblog_confirm($hiddens, $action, $msg, $submit='', $back=false) {
+    global $xoopsGTicket ;
     $submit = ($submit != '') ? trim($submit) : _SUBMIT;
     echo '<div class="confirmMsg"><h4>'.$msg.'</h4><form method="post" action="'.$action.'">';
+    $input_hidden = "" ;
     foreach ($hiddens as $name => $value) {
         if (is_array($value)) {
             foreach ($value as $caption => $newvalue) {
-                echo '<input type="radio" name="'.$name.'" value="'.$newvalue.'" /> '.$caption;
+                $input_hidden .= '<input type="radio" name="'.$name.'" value="'.$newvalue.'" /> '.$caption;
             }
-            echo '<br />';
+            $input_hidden .= '<br />';
         } else {
-            echo '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
+            $input_hidden .= '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
         }
     }
-    echo '<input type="submit" name="continue" value="'.$submit.'" /></form></div>';
+    echo $input_hidden . '<input type="submit" name="continue" value="'.$submit.'" /></form>';
+    if( $back ){
+        $input_hidden_back = "" ;
+        if( isset($hiddens['op']) )
+            unset($hiddens['op']) ;
+        foreach ($hiddens as $name => $value) {
+            $input_hidden_back .= '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
+        }
+       echo '<form method="post" action="'.$action.'">' . $input_hidden_back . '<input type="submit" name="preview" value="'._CANCEL.'">' ;
+    }
+    echo '</div>';
 }
 
+
+
+
+
+
 if (is_object($xoopsUser)) {
     $currentUser = $xoopsUser;
 } else {
@@ -85,19 +103,23 @@ if ($currentuid==0 || (!$isAdmin && ($xoopsModuleConfig['adminonly'] || !$priv->
 
 // Save the post
 if (!empty($_POST['post'])) {
+  if ( ! $xoopsGTicket->check() ) {
+     redirect_header(XOOPS_URL.'/',3,$xoopsGTicket->getErrors());
+  }
   $entry =& getEntry($_POST);
   if (strlen($entry->getVar('contents', 'n')) < $xoopsModuleConfig['minentrysize']) {
     // Include the page header
     include(XOOPS_ROOT_PATH.'/header.php');
-    weblog_confirm(array('title'=>$entry->getVar('title', 'f'),
-                         'contents'=>$entry->getVar('contents', 'f'),
-                         'blog_id'=>$entry->getVar('blog_id'),
+    weblog_confirm(array('blog_id'=>$entry->getVar('blog_id'),
                          'private'=>$entry->isPrivate(),
                          'dohtml'=>!$entry->doHtml(),
                          'updateping'=>$entry->isUpdateping(),
                          'user_id'=>$entry->getVar('user_id'),
                          'cat_id'=>$entry->getVar('cat_id'),
+                         'title'=>$entry->getVar('title', 'f'),
+                         'contents'=>$entry->getVar('contents', 'f'),
                          'ent_trackbackurl'=>$entry->getVar('ent_trackbackurl'),
+                         'XOOPS_G_TICKET' => $xoopsGTicket->issue( __LINE__ ) ,
                          'continue'=>1),
                    'post.php',
                    sprintf(_BL_POST_TOO_SMALL, $xoopsModuleConfig['minentrysize'],
@@ -167,7 +189,6 @@ if (!empty($_POST['post'])) {
     if( trim($entry->getVar('ent_trackbackurl' , 'n')) || $old_trackbackurl ){
         $blog_name = $xoopsModule->name() . " - " . sprintf(_BL_WHOS_BLOG,$xoopsUser->getVar('uname','E')) . " - " . $xoopsConfig['sitename'] ;
         $blog_url = sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $xoopsModule->dirname(),$entry->getVar('blog_id')) ;
-
         $tb_operator->Create_Trackback_Data( $entry , $blog_name , $blog_url ) ;
         $trackback =& $tb_operator->newInstance() ;
         foreach( $tb_operator->Get_Trackback_Url( $entry , $old_trackbackurl ) as $trackback_url=>$type ){
@@ -206,7 +227,7 @@ if (!empty($_POST['post'])) {
     if( $entry->isUpdateping() ){
         include_once(sprintf('%s/modules/%s/class/class.commonping.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
         $weblog_url = sprintf('%s/modules/%s/', XOOPS_URL, $xoopsModule->dirname() ) ;
-        if( ! $blog_name )
+        if( ! isset($blog_name) )
             $blog_name = $xoopsModule->name() . " - " . sprintf(_BL_WHOS_BLOG,$xoopsUser->getVar('uname','E')) . " - " . $xoopsConfig['sitename'] ;
         $Common_Updateping =& new Weblog_Commonping( $blog_name ,  $weblog_url ) ;
         $commonping_server_file = sprintf('%s/modules/%s/language/%s/commonping_servers.inc.php', 
@@ -223,6 +244,9 @@ if (!empty($_POST['post'])) {
     exit();
   }
 } else if (!empty($_POST['delete']) || (!empty($_POST['op']) && $_POST['op'] == 'delete')) {
+  if ( ! $xoopsGTicket->check() ) {
+    redirect_header(XOOPS_URL.'/',3,$xoopsGTicket->getErrors());
+  }
   $entry =& getEntry($_POST);
   if (!empty($_POST['ok'])) {
     // After delete, return the user to the user's blog they were reading.
@@ -246,18 +270,28 @@ if (!empty($_POST['post'])) {
     }
   } else {
     require(XOOPS_ROOT_PATH.'/header.php');
-    xoops_confirm(array('op' => 'delete',
+    weblog_confirm(array(
                         'blog_id' => $entry->getVar('blog_id'),
+                        'private'=>$entry->isPrivate(),
+                        'dohtml'=>!$entry->doHtml(),
+                        'updateping'=>$entry->isUpdateping(),
+                        'user_id' => $entry->getVar('user_id'),
                         'cat_id' => $entry->getVar('cat_id'),
                         'title' => $entry->getVar('title', 'n'),
                         'contents' => $entry->getVar('contents', 'n'),
-                        'ok' => 1,
-                        'user_id' => $entry->getVar('user_id')),
-                  'post.php', sprintf(_BL_CONFIRM_DELETE, stripslashes($entry->getVar('title'))));
+                        'ent_trackbackurl'=>$entry->getVar('ent_trackbackurl'),
+                        'XOOPS_G_TICKET' => $xoopsGTicket->issue( __LINE__ ),
+                        'op' => 'delete',
+                        'ok' => 1),
+                  'post.php', sprintf(_BL_CONFIRM_DELETE, stripslashes($entry->getVar('title'))) , false ,true );
     require(XOOPS_ROOT_PATH.'/footer.php');
   }
 } else {
   // Edit/Create/Preview the post
+  if( ! empty($_POST['preview']) || ! empty($_POST['continue']) ){  // in case of Preview|Continue check GTicket
+    if ( ! $xoopsGTicket->check() )
+       redirect_header(XOOPS_URL.'/',3,$xoopsGTicket->getErrors());
+  }
   $blog_id=!empty($_GET['blog_id']) ? $_GET['blog_id'] : 0;
   if ($blog_id>0 && empty($_POST['preview'])) {
     $entry =& $weblog->getEntry($currentuid, $blog_id) ;
@@ -283,7 +317,7 @@ if (!empty($_POST['post'])) {
   $xoopsOption['template_main'] = 'weblog_post.html';
   include_once XOOPS_ROOT_PATH."/include/xoopscodes.php";
 
-  if( isset($recieved_trackback) && count($recieved_trackback)>0 ){
+  if( isset($recieved_trackback) && is_array($recieved_trackback) && count($recieved_trackback)>0 ){
       $recieved_trackback_url_array = array();
       foreach( $recieved_trackback as $trackback_obj ){
           $recieved_trackback_url_array[] = $trackback_obj->getVar('tb_url') ;
@@ -299,6 +333,7 @@ if (!empty($_POST['post'])) {
   $blog_form = new XoopsThemeForm(_BL_POST, 'blogform', "post.php");
   $blog_form->addElement(new XoopsFormHidden('user_id',$entry->getVar('user_id')));
   $blog_form->addElement(new XoopsFormHidden('blog_id',$entry->getVar('blog_id')));
+  $blog_form->addElement($xoopsGTicket->getTicketXoopsForm( __LINE__ ));
   if ($xoopsModuleConfig['minentrysize'] > 0) {
     $blog_form->addElement(new XoopsFormLabel('',sprintf(_BL_POST_MUST_BE,
                                                          $xoopsModuleConfig['minentrysize'])));
@@ -312,7 +347,42 @@ if (!empty($_POST['post'])) {
                                                     $entry->getVar('contents', 'e'),
                                                     $xoopsModuleConfig['editorheight'],
                                                     $xoopsModuleConfig['editorwidth']), true);
-
+	// add image manager
+	if( isset($xoopsModuleConfig['use_imagemanager']) && $xoopsModuleConfig['use_imagemanager'] ){
+		$imagemanager_valid = false ;
+		// check GD2 module extension is loaded or not.
+		if( function_exists("gd_info") ){
+			$gd_infomation = gd_info() ;
+			if( substr( $gd_infomation['GD Version'] , 0 , 10 ) == 'bundled (2' )	// GD version 2 is required
+				$imagemanager_valid = true ;
+		}
+		if( $imagemanager_valid ){
+			$imagemanager_tag = sprintf('<img onmouseover=\'style.cursor="hand"\' onclick=\'javascript:openWithSelfMain("%s/modules/%s/weblog-imagemanager.php?target=contents","imgmanager",400,430);\' src="%s/modules/%s/images/weblog_imagemanager.gif" alt="image" />' ,
+                                                            XOOPS_URL , $xoopsModule->dirname() , XOOPS_URL , $xoopsModule->dirname() );
+		}else{
+			$imagemanager_tag = _BL_WEBLOG_IMAGEMANAGER_CAUTION ;
+		}
+		$imagemanager_tray = new XoopsFormElementTray( _BL_WEBLOG_IMAGEMANAGER ,'');
+		$imagemanager_button = new XoopsFormLabel('' , $imagemanager_tag ) ;
+		$imagemanager_tray->addElement($imagemanager_button) ;
+	    $blog_form->addElement($imagemanager_tray) ;
+	}
+	// add devide entry separator
+	if( isset($xoopsModuleConfig['use_separator']) && $xoopsModuleConfig['use_separator'] ){
+	    $separator_tray = new XoopsFormElementTray( _BL_ENTRY_SEPARATOR ,'');
+		$separator_button = new XoopsFormButton(_BL_ENTRY_SEPARATOR_CAPTION . "<br />" , '' , _BL_ENTRY_SEPARATOR_VALUE , 'button') ;
+		$separator_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . _BL_ENTRY_SEPARATOR_DELIMETER . "\\n\");'") ;
+		$separator_tray->addElement($separator_button) ;
+	    $blog_form->addElement($separator_tray) ;
+	}
+	// add member only javascript
+	if( isset($xoopsModuleConfig['use_memberonly']) && $xoopsModuleConfig['use_memberonly'] ){
+	    $membershow_tray = new XoopsFormElementTray( _BL_MEMBER_ONLY_READ ,'');
+		$membershow_button = new XoopsFormButton(_BL_MEMBER_ONLY_READ_CAPTION . "<br />" , '' , _BL_MEMBER_ONLY_READ_VALUE , 'button') ;
+		$membershow_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . MEMBER_ONLY_READ_DELIMETER . "\\n\");'") ;
+		$membershow_tray->addElement($membershow_button) ;
+	    $blog_form->addElement($membershow_tray) ;
+	}
     // options check box
     $checkbox_tray = new XoopsFormElementTray(_BL_OPTIONS ,'<br />');
     $checkbox_dohtml = new XoopsFormCheckBox('', 'dohtml', !$entry->doHtml());
@@ -354,7 +424,6 @@ if (!empty($_POST['post'])) {
   $button_tray->addElement(new XoopsFormButton('', 'preview', _BL_PREVIEW_BUTTON, 'submit'));
   $button_tray->addElement(new XoopsFormButton('', 'post', _BL_POST_BUTTON, 'submit'));
   $blog_form->addElement($button_tray);
-
   $xoopsTpl->assign('form', $blog_form->render());
 
   if (!empty($_POST['preview'])) {
@@ -367,7 +436,7 @@ if (!empty($_POST['post'])) {
       if (!empty($avatar) && $avatar != 'blank.gif') {
         $use_avatar = 1;
         $avatar_img = sprintf('%s/uploads/%s', XOOPS_URL, $avatar);
-        $dimension = getimagesize($avatar_img);
+        $dimension = ( ini_get('allow_url_fopen') ) ? getimagesize($avatar_img) : "" ;;
         $avatar_width = $dimension[0];
       }
     }
